@@ -1,6 +1,6 @@
-package Pcore::Selenium v0.1.5;
+package Pcore::Selenium v0.2.0;
 
-use Pcore -class;
+use Pcore -dist, -class;
 
 1;
 __END__
